# Album image util

> **ℹ Note:** This project is on `pip` so I can use it on other machines, you'll probably not find a
> use case for as it is ultra-specific

️
This is a project for my Album of the day website, which is a website where I post my writing about albums:
one every day. The album of the days were initially written in image form. To get them on the website, I had to do some OCR-reading of previous album
image files. This library can extract different parts of these images (because I used the same template for all of them).
It can also create new album of the day images.